# ordipool
![ci](https://github.com/twosatsmaxi/ordipool/actions/workflows/ci.yml/badge.svg)

A mempool sdk library tailored for multiple usecases including ordinals

## Get started
### Installation
```bash
pip install ordipool
```

#### Check out tests in `tests/` to explore the library
It has following tests written:
- `test_mempoolio.py` - tests for mempool sdk
- `test_transaction_info.py` - tests for transaction info model and methods
- `test_utils.py` - tests for utility functions

#### Local Setup
```bash
pip install -r requirements.txt
```


#### Run tests
```bash
python -m unittest discover tests
```

## Contributing
- Create an issue to discuss about the feature/bug
- Fork the repo
- Create a branch
- Make changes
- Create a PR
- Get it reviewed and merged
- Celebrate 🎉